---
sidebar_position: 1
---

# The ChemFuseKit Cookbook: an introduction

*What is a cookbook, exactly?*

> A cookbook is a comprehensive collection of recipes that guide users through
the process of learning and mastering the use of a specific library or
programming technique, by providing step-by-step instructions, explanations and
examples.

## What you'll learn

In this cookbook you will learn the basic principles of operation of `ChemFuseKit` through practical examples and case studies. You will be shown that all modules follow a basic structure, and once you've learned it for one module, you will be able to reapply that knowledge for all modules.

You will be shown how to use the library on its own, and also how to use it as a part of a bigger pipeline.

## Cookbook sectioning

Here we go:

- first of all, you will be shown the basic principles and structure;
- then, you will be shown three case studies;
- finally, you'll receive instructions on how to modify and expand this library for your own purposes.